@@ -36,7 +36,7 @@
 //!
 //! See [`serialize`] module for more information.
 #![no_std]
-#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(doc_cfg, feature(doc_cfg))]
 extern crate alloc;
 extern crate core;
 
@@ -52,10 +52,11 @@ pub use crate::yaml::*;
 /// Literals and expressions will be transformed to [`Yaml`] automatically by calling [`Into::into`].
 ///
 /// ```
-/// use yaml_peg::node;
+/// use yaml_peg::{node, Node};
 ///
 /// let k = "a";
 /// assert_eq!(node!(k), node!("a"));
+/// assert_eq!(node!(()), Node::from(()));
 /// ```
 ///
 /// Arrays and maps can be created from this macro directly through brackets (`[]`, `{}`).
@@ -63,16 +64,15 @@ pub use crate::yaml::*;
 /// ```
 /// use yaml_peg::{node, yaml_array, yaml_map};
 ///
-/// assert_eq!(node!([node!(1), node!(2)]), node!(yaml_array![node!(1), node!(2)]));
-/// assert_eq!(node!({node!(1) => node!(2)}), node!(yaml_map![node!(1) => node!(2)]));
+/// assert_eq!(node!([1, 2]), node!(yaml_array![1, 2]));
+/// assert_eq!(node!({1 => 2}), node!(yaml_map! { 1 => 2 }));
 /// ```
 ///
-/// The [`YamlBase::Null`] and the [`YamlBase::Null`] are also supported by the syntax:
+/// The [`YamlBase::Anchor`] is also supported by the syntax:
 ///
 /// ```
 /// use yaml_peg::{node, YamlBase};
 ///
-/// assert_eq!(node!(YamlBase::Null), node!(null));
 /// assert_eq!(node!(YamlBase::Anchor("x".into())), node!(*"x"));
 /// ```
 ///
@@ -83,13 +83,10 @@ macro_rules! node {
         $crate::node!($crate::yaml_array![$($token)*])
     };
     ({$($token:tt)*}) => {
-        $crate::node!($crate::yaml_map![$($token)*])
-    };
-    (null) => {
-        $crate::node!($crate::Yaml::Null)
+        $crate::node!($crate::yaml_map! { $($token)* })
     };
     (*$anchor:expr) => {
-        $crate::node!($crate::Yaml::Anchor($anchor.into()))
+        $crate::node!($crate::YamlBase::Anchor($anchor.into()))
     };
     ($yaml:expr) => {
         $crate::Node::from($yaml)
@@ -99,6 +96,12 @@ macro_rules! node {
 /// Create [`ArcNode`] items literally.
 ///
 /// The API is same as [`node!`] macro.
+///
+/// ```
+/// use yaml_peg::{node_arc as node, ArcNode};
+///
+/// assert_eq!(node!(()), ArcNode::from(()));
+/// ```
 #[macro_export]
 macro_rules! node_arc {
     ([$($token:tt)*]) => {
@@ -107,75 +110,78 @@ macro_rules! node_arc {
     ({$($token:tt)*}) => {
         $crate::node_arc!($crate::yaml_map![$($token)*])
     };
-    (null) => {
-        $crate::node_arc!($crate::Yaml::Null)
-    };
     (*$anchor:expr) => {
-        $crate::node_arc!($crate::Yaml::Anchor($anchor.into()))
+        $crate::node_arc!($crate::YamlBase::Anchor($anchor.into()))
     };
     ($yaml:expr) => {
-        $crate::ArcNode::new($yaml.into(), 0, "", "")
+        $crate::ArcNode::from($yaml)
     };
 }
 
 /// Create [`YamlBase::Array`] items literally.
 ///
-/// ```
-/// use yaml_peg::{node, yaml_array};
+/// All items will convert to [`NodeBase`] automatically.
 ///
-/// yaml_array![node!("a"), node!("b"), node!("c")];
+/// ```
+/// use yaml_peg::{node, yaml_array, Yaml};
+///
+/// assert_eq!(
+///     yaml_array!["a", "b", "c"],
+///     Yaml::Array(vec![node!("a"), node!("b"), node!("c")])
+/// );
 /// ```
 #[macro_export]
 macro_rules! yaml_array {
-    ($($token:tt)*) => {
-        $crate::YamlBase::Array(vec![$($token)*])
-    };
+    ($v:expr; $n:expr) => {{
+        extern crate alloc;
+        $crate::YamlBase::Array(alloc::vec![$crate::NodeBase::from($v); $n])
+    }};
+    ($($v:expr),* $(,)?) => {{
+        extern crate alloc;
+        $crate::YamlBase::Array(alloc::vec![$($crate::NodeBase::from($v)),*])
+    }};
 }
 
 /// Create [`YamlBase::Map`] items literally.
 ///
-/// ```
-/// use yaml_peg::{node, yaml_map};
+/// All items will convert to [`NodeBase`] automatically.
 ///
-/// yaml_map!{
-///     node!("a") => node!("b"),
-///     node!("c") => node!("d"),
-/// };
+/// ```
+/// use yaml_peg::{node, yaml_map, Yaml};
+///
+/// assert_eq!(
+///     yaml_map! { "a" => "b", "c" => "d" },
+///     Yaml::Map(vec![(node!("a"), node!("b")), (node!("c"), node!("d"))].into_iter().collect())
+/// );
 /// ```
 #[macro_export]
 macro_rules! yaml_map {
-    (@) => { $crate::Map::new() };
-    (@$expr:expr) => { $expr };
-    ($($k1:expr => $v1:expr $(, $k2:expr => $v2:expr)* $(,)?)?) => {
-        $crate::YamlBase::Map($crate::yaml_map!(@$({
-            let mut m = $crate::Map::new();
-            m.insert($k1, $v1);
-            $(m.insert($k2, $v2);)*
-            m
-        })?))
-    };
+    ($($k:expr => $v:expr),* $(,)?) => {{
+        extern crate alloc;
+        $crate::YamlBase::Map(alloc::vec![
+            $(($crate::NodeBase::from($k), $crate::NodeBase::from($v))),*
+        ].into_iter().collect())
+    }};
 }
 
 /// Create a custom anchor visitor.
 ///
 /// The anchor name should implement [`alloc::string::ToString`] trait.
+/// All items will convert to [`NodeBase`] automatically.
 ///
 /// ```
 /// use yaml_peg::{node, anchors};
 ///
 /// let v = anchors![
-///     "my-boss" => node!({node!("name") => node!("Henry")}),
+///     "my-boss" => node!({"name" => "Henry"}),
 /// ];
 /// assert_eq!(v["my-boss"]["name"], node!("Henry"));
 /// ```
 #[macro_export]
 macro_rules! anchors {
-    () => {
-        $crate::AnchorBase::new()
-    };
-    ($k1:expr => $v1:expr $(, $k2:expr => $v2:expr)* $(,)?) => {{
-        use core::iter::FromIterator;
-        $crate::AnchorBase::from_iter(vec![($k1.to_string(), $v1) $(, ($k2.to_string(), $v2))*])
+    ($($k:expr => $v:expr),* $(,)?) => {{
+        extern crate alloc;
+        alloc::vec![$(($k.to_string(), $crate::NodeBase::from($v))),*].into_iter().collect::<$crate::AnchorBase<_>>()
     }};
 }
 
@@ -186,7 +192,7 @@ mod node;
 pub mod parser;
 pub mod repr;
 #[cfg(feature = "serialize")]
-#[cfg_attr(docsrs, doc(cfg(feature = "serialize")))]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "serialize")))]
 pub mod serialize;
 #[cfg(test)]
 mod tests;
