@@ -1,5 +1,6 @@
 use crate::{repr::*, *};
 use alloc::string::ToString;
+use core::ops::Deref;
 use core::{
     fmt::{Debug, Formatter, Result as FmtResult},
     hash::Hash,
@@ -39,17 +40,13 @@ macro_rules! as_num_method {
 }
 
 macro_rules! impl_iter {
-    ($item:ty) => {
-        impl<R: Repr> FromIterator<$item> for NodeBase<R> {
+    ($(impl $item:ty)+) => {
+        $(impl<R: Repr> FromIterator<$item> for NodeBase<R> {
             fn from_iter<T: IntoIterator<Item = $item>>(iter: T) -> Self {
                 Self::from(iter.into_iter().collect::<YamlBase<R>>())
             }
-        }
+        })+
     };
-    ($item1:ty $(, $item2:ty)*) => {
-        impl_iter!{$item1}
-        $(impl_iter!{$item2})*
-    }
 }
 
 /// A node with [`alloc::rc::Rc`] holder.
@@ -82,14 +79,14 @@ pub type ArcNode = NodeBase<ArcRepr>;
 /// ```
 /// use yaml_peg::{node, Ind};
 ///
-/// let n = node!([node!("a"), node!("b"), node!("c")]);
+/// let n = node!(["a", "b", "c"]);
 /// assert_eq!(node!("b"), n[Ind(1)]);
 /// ```
 ///
 /// ```should_panic
 /// use yaml_peg::{node, Ind};
 ///
-/// let n = node!(null);
+/// let n = node!(());
 /// let n = &n["a"][Ind(0)]["b"];
 /// ```
 ///
@@ -107,7 +104,7 @@ pub type ArcNode = NodeBase<ArcRepr>;
 ///
 /// fn main() -> Result<(), (&'static str, u64)> {
 ///     let n = node!({
-///         node!("title") => node!(12.)
+///         "title" => 12.
 ///     });
 ///     let n = n.get("title").map_err(|p| ("missing \"title\"", p))?;
 ///     assert_eq!(
@@ -139,9 +136,9 @@ pub type ArcNode = NodeBase<ArcRepr>;
 /// let a = node!("a");
 /// {
 ///     let b = a.clone();
-///     assert_eq!(2, Rc::strong_count(b.as_ref()));
+///     assert_eq!(2, Rc::strong_count(&b));
 /// }
-/// assert_eq!(1, Rc::strong_count(a.as_ref()));
+/// assert_eq!(1, Rc::strong_count(&a));
 /// ```
 ///
 /// If you want to copy data, please get the data first.
@@ -150,8 +147,8 @@ pub struct NodeBase<R: Repr>(pub(crate) R);
 
 impl<R: Repr> NodeBase<R> {
     /// Create node from YAML data.
-    pub fn new(yaml: YamlBase<R>, pos: u64, ty: &str, anchor: &str) -> Self {
-        Self(R::repr(yaml, pos, ty.to_string(), anchor.to_string()))
+    pub fn new(yaml: YamlBase<R>, pos: u64, tag: &str, anchor: &str) -> Self {
+        Self(R::repr(yaml, pos, tag.to_string(), anchor.to_string()))
     }
 
     /// Document position.
@@ -160,10 +157,10 @@ impl<R: Repr> NodeBase<R> {
         self.0.as_ref().pos
     }
 
-    /// Type assertion.
+    /// Tag.
     #[inline(always)]
-    pub fn ty(&self) -> &str {
-        &self.0.as_ref().ty
+    pub fn tag(&self) -> &str {
+        &self.0.as_ref().tag
     }
 
     /// Anchor reference.
@@ -243,7 +240,7 @@ impl<R: Repr> NodeBase<R> {
         /// use yaml_peg::node;
         ///
         /// assert_eq!("abc", node!("abc").as_str().unwrap());
-        /// assert!(node!(null).as_str().unwrap().is_empty());
+        /// assert!(node!(()).as_str().unwrap().is_empty());
         /// ```
         fn as_str = Str | ("")? -> &str
     }
@@ -260,7 +257,7 @@ impl<R: Repr> NodeBase<R> {
     /// assert_eq!("12.04", node!(12.04).as_value().unwrap());
     /// assert_eq!("true", node!(true).as_value().unwrap());
     /// assert_eq!("false", node!(false).as_value().unwrap());
-    /// assert!(node!(null).as_value().unwrap().is_empty());
+    /// assert!(node!(()).as_value().unwrap().is_empty());
     /// ```
     pub fn as_value(&self) -> Result<&str, u64> {
         match self.yaml() {
@@ -281,13 +278,13 @@ impl<R: Repr> NodeBase<R> {
     /// use yaml_peg::{node, anchors};
     ///
     /// let node_a = node!(*"a");
-    /// let v = anchors!["a" => node!(20.)];
+    /// let v = anchors!["a" => 20.];
     /// assert_eq!(20., node_a.as_anchor(&v).as_float().unwrap());
     /// ```
     pub fn as_anchor<'a, 'b: 'a>(&'a self, v: &'b AnchorBase<R>) -> &'a Self {
         match self.yaml() {
             YamlBase::Anchor(s) if v.contains_key(s) => v.get(s).unwrap(),
-            _ => &self,
+            _ => self,
         }
     }
 
@@ -297,7 +294,7 @@ impl<R: Repr> NodeBase<R> {
         /// ```
         /// use yaml_peg::node;
         ///
-        /// let n = node!([node!("55")]);
+        /// let n = node!(["55"]);
         /// assert_eq!(node!("55"), n.as_array().unwrap()[0]);
         /// for n in n.as_array().unwrap() {
         ///     assert_eq!(node!("55"), n);
@@ -312,7 +309,7 @@ impl<R: Repr> NodeBase<R> {
         /// ```
         /// use yaml_peg::node;
         ///
-        /// let n = node!({node!(1) => node!(2)});
+        /// let n = node!({1 => 2});
         /// assert_eq!(node!(2), n.as_map().unwrap()[&node!(1)]);
         /// for (k, v) in n.as_map().unwrap() {
         ///     assert_eq!(node!(1), k);
@@ -415,7 +412,7 @@ impl<R: Repr> NodeBase<R> {
     /// # fn main() -> Result<(), u64> {
     /// use yaml_peg::{anchors, node, Node};
     ///
-    /// let v = anchors!["c" => node!(10)];
+    /// let v = anchors!["c" => 10];
     /// let a = node!({node!("a") => node!({node!("b") => node!(*"c")})});
     /// let c = a.get("a")?.with(&v, "b", 0, Node::as_int)?;
     /// assert_eq!(10, c);
@@ -474,6 +471,15 @@ impl<R: Repr> Debug for NodeBase<R> {
     }
 }
 
+impl<R: Repr> Deref for NodeBase<R> {
+    type Target = R::Target;
+
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        self.0.deref()
+    }
+}
+
 /// Node index indicator use to indicate array position.
 pub struct Ind(pub usize);
 
@@ -516,4 +522,7 @@ where
     }
 }
 
-impl_iter! {Self, (Self, Self)}
+impl_iter! {
+    impl Self
+    impl (Self, Self)
+}
