@@ -10,7 +10,7 @@ pub enum PError {
     /// If parser mismatched, just choose another one.
     Mismatch,
     /// The parser is the only one can be matched.
-    Terminate(u64, String),
+    Terminate(u64, &'static str),
 }
 
 impl PError {
@@ -25,12 +25,6 @@ impl PError {
     }
 }
 
-impl From<()> for PError {
-    fn from(_: ()) -> Self {
-        Self::Mismatch
-    }
-}
-
 impl Display for PError {
     fn fmt(&self, f: &mut Formatter) -> Result {
         f.write_fmt(format_args!("{:?}", self))
