@@ -4,6 +4,7 @@
 //! and [`Arc`] is the multiple thread reference counter.
 use crate::*;
 use alloc::{rc::Rc, string::String, sync::Arc};
+use core::ops::Deref;
 use core::{
     fmt::{Debug, Formatter, Result as FmtResult},
     hash::{Hash, Hasher},
@@ -22,7 +23,7 @@ pub struct ArcRepr(Arc<Inner<Self>>);
 #[derive(Eq, Clone)]
 pub struct Inner<R: Repr> {
     pub(crate) pos: u64,
-    pub(crate) ty: String,
+    pub(crate) tag: String,
     pub(crate) anchor: String,
     pub(crate) yaml: YamlBase<R>,
 }
@@ -48,18 +49,18 @@ impl<R: Repr> PartialEq for Inner<R> {
 /// The generic representation holder for [`YamlBase`] and [`NodeBase`].
 ///
 /// See the implementor list for the choose.
-pub trait Repr: AsRef<Inner<Self>> + Hash + Eq + Clone + Debug {
-    fn repr(yaml: YamlBase<Self>, pos: u64, ty: String, anchor: String) -> Self;
+pub trait Repr: AsRef<Inner<Self>> + Deref + Hash + Eq + Clone + Debug {
+    fn repr(yaml: YamlBase<Self>, pos: u64, tag: String, anchor: String) -> Self;
     fn into_yaml(self) -> YamlBase<Self>;
 }
 
 macro_rules! impl_repr {
     ($ty:ty, $inner:ident) => {
         impl Repr for $ty {
-            fn repr(yaml: YamlBase<Self>, pos: u64, ty: String, anchor: String) -> Self {
+            fn repr(yaml: YamlBase<Self>, pos: u64, tag: String, anchor: String) -> Self {
                 Self($inner::new(Inner {
                     pos,
-                    ty,
+                    tag,
                     anchor,
                     yaml,
                 }))
@@ -78,14 +79,17 @@ macro_rules! impl_repr {
         }
 
         impl AsRef<Inner<Self>> for $ty {
+            #[inline(always)]
             fn as_ref(&self) -> &Inner<Self> {
                 &self.0
             }
         }
 
-        impl AsRef<$inner<Inner<$ty>>> for NodeBase<$ty> {
-            fn as_ref(&self) -> &$inner<Inner<$ty>> {
-                &self.0 .0
+        impl Deref for $ty {
+            type Target = $inner<Inner<Self>>;
+            #[inline(always)]
+            fn deref(&self) -> &Self::Target {
+                &self.0
             }
         }
     };
