@@ -7,31 +7,23 @@ use core::iter::FromIterator;
 use ritelinked::LinkedHashMap;
 
 macro_rules! impl_from {
-    ($from_ty:ty => $ty:ident) => {
-        impl<R: Repr> From<$from_ty> for YamlBase<R> {
+    ($(impl $($from_ty:ty),+ => $ty:ident)+) => {
+        $($(impl<R: Repr> From<$from_ty> for YamlBase<R> {
             fn from(s: $from_ty) -> Self {
                 Self::$ty(s.to_string())
             }
-        }
-    };
-    ($($ty1:ty $(, $ty2:ty)* => $ty:ident)+) => {
-        $(impl_from! {$ty1 => $ty}
-        $(impl_from! {$ty2 => $ty})*)+
+        })+)+
     };
 }
 
 macro_rules! impl_iter {
-    ($item:ty => $ty:ident) => {
-        impl<R: Repr> FromIterator<$item> for YamlBase<R> {
+    ($(impl $($item:ty),+ => $ty:ident)+) => {
+        $($(impl<R: Repr> FromIterator<$item> for YamlBase<R> {
             fn from_iter<T: IntoIterator<Item = $item>>(iter: T) -> Self {
                 Self::$ty(iter.into_iter().collect())
             }
-        }
+        })+)+
     };
-    ($($item1:ty $(, $item2:ty)* => $ty:ident)+) => {
-        $(impl_iter!{$item1 => $ty}
-        $(impl_iter!{$item2 => $ty})*)+
-    }
 }
 
 /// A YAML data with [`alloc::rc::Rc`] holder.
@@ -62,9 +54,9 @@ pub type Map<R> = LinkedHashMap<NodeBase<R>, NodeBase<R>>;
 ///
 /// use std::iter::FromIterator;
 /// let v = vec![node!(1), node!(2), node!(3)];
-/// assert_eq!(Yaml::from_iter(v), yaml_array![node!(1), node!(2), node!(3)]);
+/// assert_eq!(Yaml::from_iter(v), yaml_array![1, 2, 3]);
 /// let m = vec![(node!(1), node!(2)), (node!(3), node!(4))];
-/// assert_eq!(Yaml::from_iter(m), yaml_map!{node!(1) => node!(2), node!(3) => node!(4)});
+/// assert_eq!(Yaml::from_iter(m), yaml_map! { 1 => 2, 3 => 4});
 /// ```
 #[derive(Hash, Eq, PartialEq, Debug, Clone)]
 pub enum YamlBase<R: Repr> {
@@ -108,9 +100,9 @@ impl<R: Repr> From<bool> for YamlBase<R> {
 }
 
 impl_from! {
-    char, &str, String, &String => Str
-    usize, u8, u16, u32, u64, u128, isize, i8, i16, i32, i64, i128 => Int
-    f32, f64 => Float
+    impl char, &str, String, &String => Str
+    impl usize, u8, u16, u32, u64, u128, isize, i8, i16, i32, i64, i128 => Int
+    impl f32, f64 => Float
 }
 
 impl<R: Repr> From<Array<R>> for YamlBase<R> {
@@ -126,6 +118,6 @@ impl<R: Repr> From<Map<R>> for YamlBase<R> {
 }
 
 impl_iter! {
-    NodeBase<R> => Array
-    (NodeBase<R>, NodeBase<R>) => Map
+    impl NodeBase<R> => Array
+    impl (NodeBase<R>, NodeBase<R>) => Map
 }
